import { select, 
        json,
        csv,
        tsv, 
        geoPath,
        geoEquirectangular,
        scaleOrdinal,
        schemeCategory10,
        zoom,
        event } from 'd3';
import { feature } from 'topojson';

const svg = select('svg');
const width = parseFloat(svg.attr('width'));
const height = +svg.attr('height');
let stateNames = [];
//specifies the dimensions of the SVG graphic
const projection = geoEquirectangular()
			.clipExtent([[0,0],[width,height]])
			.center([500, 30])
			.scale(450);

const pathGenerator = geoPath()
		.projection(projection);

const g = svg.append('g');

svg.call(zoom().on('zoom', () => {
	g.attr('transform', event.transform)
}));

//loading json data from my gist
Promise.all([json('https://gist.githubusercontent.com/AISWARYAMARAPATLA1999/22d0e04cc050111f0b039154415539fb/raw/0613df4564f8cd48b0cf1952ac9ecd1dfa57c37e/Country.csv'),
             json('https://gist.githubusercontent.com/AISWARYAMARAPATLA1999/22d0e04cc050111f0b039154415539fb/raw/0613df4564f8cd48b0cf1952ac9ecd1dfa57c37e/Country.csv')
            ]).then(([stateJSON, districtJSON]) => {
	 
  const stateGroup = g.append('g');
  //simplification process for having efficient map
  			
  const states = feature(stateJSON, stateJSON.objects.CHN_adm1);
  
  const colorScale = scaleOrdinal(schemeCategory10);
  
  const statePath = stateGroup.selectAll('path')
    .data(states.features)
  statePath.enter().append('path')
    .attr('class', 'states')
    .attr('d', d => pathGenerator(d))
});
      